import unittest

class Test(unittest.TestCase):
    def test(self):
        from naotw.winman import where 
        import os 
        cmdexe = fr'{os.environ["SystemRoot"]}\System32\cmd.exe'.upper()
        self.assertIn(cmdexe, [exe.upper() for exe in where('cmd')])

if __name__ == '__main__':
    unittest.main()



import unittest

class Test(unittest.TestCase):
    def test(self):
        from naotw.gpt import 檔案內容轉譯議會備詢提問並複製剪貼簿
        from pathlib import Path
        import clipboard
        import os, sys
        f = Path(__file__).parent / '112財稅局重審核定.docx'
        檔案內容轉譯議會備詢提問並複製剪貼簿(f)
        self.assertEqual(len(clipboard.paste()), 3338)
        clipboard.copy("") 
        os.system(f'{sys.executable} -m naotw.gpt --file2inquery "{f}"') 
        self.assertEqual(len(clipboard.paste()), 3338)

    def test_clipboard_trans(self):
        from naotw.gpt import 剪貼簿內容轉譯議會備詢提問
        import clipboard
        import os, sys
        t = clipboard.copy('a aa')
        os.system(f'{sys.executable} -m naotw.gpt --clipboard2inquery') 
        self.assertEqual(len(clipboard.paste()), 2277)

if __name__ == '__main__':
    import logging
    logging.basicConfig(level=logging.INFO)
    unittest.main()



from pathlib import Path
import logging
logger = logging.getLogger(Path(__file__).stem)

def 轉譯議會備詢提問(原始內容): 
    return f'''
在台灣省宜蘭縣，審計部臺灣省宜蘭縣審計室會到宜蘭縣議會接受縣議員質詢，就過去查核宜蘭縣政府暨所屬機關單位的重要審計意見，整理成備詢資料，以下5則備詢資料的範例

        第1則
        標題：宜蘭縣羅東轉運站暨附屬設施及停車空間新建工程執行情形
        內容：
(一)審核情形
縣政府辦理「宜蘭縣羅東轉運站暨附屬設施及停車空間新建工程」(下稱本工程)，計畫執行期程自108年3月至113年2月止，總經費10億6,302萬餘元(交通部公路總局補助4億8,551萬餘元，縣政府自籌5億7,750萬餘元)，於109年12月29日決標，決標金額8億5,800萬元。本工程於110年3月10日開工，工期720日曆天，預計113年2月完工。

經查其執行情形，核有：
1.	轉運站後續增建營運移轉附屬事業興建綜合大樓，建築物完成後潛存立面不規則性結構，及屋頂後續增建3層以上建築物之部分預留柱鋼筋搭接高度位於同一斷面上且未互相錯開，均核有疑慮。
2.	工程施工進度落後，且預算執行率偏低，允應妥善研訂趲趕工進策略，並強化預算編列、分配及執行之管制考核機制。

(二)機關改善情形

1.	本工程屋頂層(3F)預留柱鋼筋，採SA級續接器符合混凝土工程設計規範規定，可准許使用於任何位置，搭接高度符合規定，且於招商文件中檢附第1期工程之建造執照以及招標文件，以利促參民間機構進行建築空間及結構系統規劃，並於投資契約第5章規範民間機構承諾在增建時，應符合相關法令規定。又於招標文件增加第1期工程結構計算書圖，以利民間機構妥適規劃增建之結構系統，並於投資契約第8章「增建」中，加註需依當時法令確實檢討屋頂層(3F)預留柱鋼筋續接結構之品質及效果，以確保建築結構安全。
2.	本工程多次流標至109年12月29日始決標，廠商於110年3月申報開工，申報開工前支出僅為設計服務費以及審查作業費等，爰執行率仍屬偏低，爾後將注意預算編列執行情形，加速辦理，並依工程進度檢討經費調配額度，截至112年6月底止，本工程預定進度75.61％，實際進度77.14％，已無工進落後情形，預計於113年2月完工。

        第2則

標題：媽祖文化節執行情形

        內容：
(一)審核情形

縣政府考量嚴重特殊傳染性肺炎（COVID－19）疫情停辦110年蘭陽媽祖文化節活動，在疫情日漸趨緩下，為延續108年北臺灣媽祖文化節及109年蘭陽媽祖文化節，賡續於111年9月16至18日舉辦111年蘭陽媽祖文化節活動，計畫經費1,000萬元，實際支用數1,066萬餘元（66萬餘元係勻支同工作計畫經費）。經查計畫執行情形，核有： 1.原計畫規劃委託辦理成果報告及效益評估，惟實際僅辦理滿意度調查，仍未訂定量化績效衡量指標，難以衡量投入資源達成之活動預期效益及實際執行成效。 2.委託辦理調查雖有9成受訪民眾表示滿意，惟仍有6成受訪民眾未消費購買商品及住宿，對於促進活絡經濟效益之達成有待釐清，且尚無研議由民間主辦之評估作為。 3.媽祖文化節海巡賞鯨船運送服務採購案，部分承保項目之保險金額與契約規定有間。

(二)機關改善情形

1.該府委託學術單位辦理活動滿意度調查結果，已建立經濟產業、文化傳承交流、結合推動觀光、參與年齡年輕化及持續擴大參與宮廟量能等基礎資料，並建議將滿意度調查制度化，建立資料庫納為自我評鑑機制，將上開建議作為未來精進活動效益與成效之參考作為。 2.因疫情尚未全面解封，影響國人出遊意願；112年蘭陽媽祖文化節預算總經費450萬元，縣政府已逐漸轉型為由主祀宮廟或民間主辦，將成為行政協助角色，讓民間力量發揮最大效能。 3.爾後將納入自辦海巡運送服務檢討改善，就市面保險公司提供之理賠方式選擇最佳方案，並明定採購契約條款，確實執行違約罰則。

        第3則
        標題：少子女化對策計畫推動情形
        內容：

(一)審核情形

縣政府為配合我國少子女化對策計畫（107年－113年），於近3年度（109至111年度）分別編列經費7,835萬餘元、8,373萬餘元及1億376萬餘元，執行結果，實際數分別為6,893萬餘元、7,572萬餘元及1億32萬餘元，經查該府推動少子女化對策計畫執行情形，核有： 1. 近3年度公共化幼兒園招收人數及占比呈現逐年下降趨勢。 2. 0至2歲（未滿）嬰幼兒家外送托覆蓋率低於少子女化對策計畫績效指標，且公共托育機構設置不均。 3. 部分僱用員工100人以上之雇主未依規定提供哺（集）乳室、托兒設施或措施，且申請補助家數偏低。

(二)機關改善情形

1. 經分析有更多家長選擇以幼兒園可提供服務時間及教保服務內容作為評估標的，未來策進作為包括：逐年下修師生比，加強教保服務人員專業知能及優質服務，並研商提高課後留園開辦率之可行方案，以提高家長選讀公共化教保服務之意願，減少家長育兒負擔。 2. 將研謀提升公共化及準公共化托育服務量能，及補助家長托育費用，減輕家長育兒負擔，並持續滾動檢討提升家外送托率；另積極協助三星鄉及頭城鎮等公所申請布建公共托育設施經費補助，提升不同區位之服務量能，並視原鄉地區之托育型態，布建親子館，提供近便、整合性高之社區支持資源服務，優化托育服務。 3. 因宜蘭縣產業型態多為製造業，員工多已過生養育時期，故托兒需求低，致企業申請補助家數不多，且考量財政資源有限，有關推動職場新形態托育模式，將藉由各項活動加強宣導，積極輔導企業，以提升其申請意願。

        第4則
        標題：五結防潮閘門改善工程執行情形

        內容：
(一)審核情形
縣政府向經濟部「前瞻基礎建設計畫-水環境建設-縣市管河川及區域排水整體改善計畫」申請補助辦理五結防潮閘門改建工程(自111年8月25日第4次公告招標標案名稱修改為五結防潮閘門改善工程)，以確保五結防潮閘門防洪禦潮功能，保障冬山河排水系統集水區域範圍內民眾生命財產安全，經濟部分別於107年2月22日、110年6月22日及111年8月1日採分3期核定全額補助，計畫總經費13億9,900萬元(含用地費2,900萬元)，計畫期程為107至113年。

經查其執行情形，核有：
1.	規劃設計服務案審查及核定過程核未有效控管作業時程，規劃及基本設計作業延後完成，致延宕辦理第1次工程招標期程1年3個月，影響計畫執行效能。
2.	前3次工程招標流標檢討作業有欠周妥，後續雖依工程會意見進行調整，惟仍未能確認領標廠商未投標原因而流標。
3.	工程預算執行率欠佳，且無法依計畫期程於113年底前完成，亟待儘速完成發包作業，並督促強化計畫進度與預算執行之管制考核作為。

(二)機關改善情形

1.	本案設計監造單位中興顧問公司提送報告至召開審查會時間較長，且前置準備作業繁瑣，致作業時程有所延誤，嗣後將加強作業時程管控，俾利縮短行政作業時間，以符合實際審查需求，並確實依核定計畫預定期程執行。
2.	有關工程會意見，縣政府已逐項進行檢討，包括調整工期、經費及保固期等，亦請顧問公司盤點可能領標廠商(如曾出席說明會)及宜蘭縣內符合資格廠商逐一洽詢瞭解不願投標原因，以釐清癥結問題，並已於第7次工程採購文件中進行修改調整，後續將於流標時確切檢討流標主因，並主動瞭解廠商未投標原因，作為重新招標之依據，爾後案件將參考本工程，避免類案再次發生。
3.	本工程因多次招標流標肇致工程預算執行率欠佳，將妥善研訂工程招標策略，持續檢討廠商未投標之癥結原因，覈實針對物價上漲妥適編列預算，經依本工程採購廉政平臺第1次聯繫會議意見調整招標文件，辦理第7次招標公告。
4.	縣政府 112年5月30日及同年6月28日辦理第7次及第8次招標公告，惟仍無廠商投標而流標，已重新檢討流標原因，並續辦第9次公開招標作業。


        第5則
        標題：農業設施、農舍及未登記工廠地價稅課稅情形

        內容：
(一)審核情形

1.本室運用農地管理資訊系統下載107年3月至111年8月宜蘭縣農業設施容許使用核發案件，挑錄設施細目為「曬場」案件，經與台灣電力股份有限公司(下稱台電)提供宜蘭縣110年度營業用電戶名冊及財政稅務局稅地種類檔資料勾稽比對結果，發現農地之農業設施申請營業用電，仍徵收田賦或減免地價稅。
2.運用縣政府建設處列管101年至111年8月底止都市計畫農業用地農舍使用執照核發清冊，及縣政府委任鄉鎮市公所核發非都市土地之建築執照案件清冊，經分別與上開台電提供之營業用電戶名冊及稅地種類檔資料勾稽比對結果，部分列管都市計畫及非都市土地農地之農舍申請營業用電，仍徵收田賦或減免地價稅。
3.運用財政稅務局稅地種類檔資料與經濟部中部辦公室網站公告，截至111年11月底止宜蘭縣低污染之既有未登記工廠經核定申請納管名冊及臨時登記工廠核准轉為特定工廠登記名冊等檔案勾稽比對結果，發現課徵田賦或減免地價稅之農地，為核定申請納管之低污染既有未登記工廠，或經核准轉為特定工廠之臨時登記工廠，惟未改課地價稅。

(二)機關改善情形

改課及補徵地價稅共計52筆、金額56萬餘元，並釐正土地地價稅稅籍資料。 
  
        請將下列的資料內容，仿照上面3則資訊發布的標題與架構內容規則，寫成1則資訊發布：
        資料內容如下：
[
{原始內容}
]
提醒，請注意：
1.簡化標題，標題文字僅簡要敘述政策、法規或計畫執行情形。
2.內容分為2項，（一）審核情形：包含2段，第1段簡要敘述行政機關執行計畫概況，第2段為審計室審核情形，以「經查計畫執行情形，核有：」開頭，後分項簡短摘述查核意見內容，但不包含據復之內容； (二)機關改善情形，對應前面各項的查核意見，摘述機關改善情形。
3.盡量維持審計室習慣的用語，不要改成白話文。
'''

def 轉譯資訊發布提問(原始內容): 
    return f'''在台灣，請用繁體中文回答。以下我將提供審計部臺灣省宜蘭縣審計室對於追蹤查核意見後續改善情形後，所辦理的3則資訊發布標題與架構內容給您參考。

        第1則 
        標題：宜蘭縣部分建築物公共安全及消防安全檢查作業未臻周妥，審計機關促請改善
        內容：
        宜蘭縣政府(下稱縣政府)及所屬消防局(下稱消防局)執行建築物公共安全及消防安全檢查作業，經審計部臺灣省宜蘭縣審計室查核發現，部分供公眾使用之建築物有逾期或漏未申報公共安全或消防安全設備檢查，及停歇業場所未予列管等情事，經函請檢討改善，已完成建築物(場所)申報及加強停歇業場所之列管與追蹤，並訂定統一裁罰基準，保障民眾生命財產及維護公共安全。
        審計室指出，依建築法第77條第3項規定，供公眾使用之建築物，應由建築物所有權人、使用人定期委託中央主管建築機關認可之專業機構或人員檢查簽證，其檢查簽證結果應向當地主管建築機關申報；消防法第9條第1項規定，各類場所之管理權人，應定期檢修消防安全設備；其檢修結果，應依規定期限報請場所所在地主管機關審核，場所有歇業或停業之情形者，亦同。截至111年底止，縣政府及消防局列管應申報建築物公共安全及消防安全檢查之建築物或場所，計有6,547處及11,084處。
        然而，審計室於112年2月查核發現，列管項目中逾期未完成建築物公共安全申報者16處、漏未申報建築物公共安全者有10處、漏未申報消防安全設備檢查者有4處，又對於違反上述有關建築法之規定者，尚未訂定統一裁罰基準，另消防局對於停歇業場所及其使用現況尚無列管資料，管理作業有欠周妥，審計室遂於112年3月函請縣政府及消防局檢討改善。
        審計室表示，經追蹤改善情形，縣政府及消防局已督促所有權人或管理權人等依規定辦理申報，截至112年底止，上述30處逾期或漏未申報者均已完成申報審查作業；又停歇業場所經清查後，計有253處均已列管追蹤使用情形，保障民眾生命財產及維護公共安全。另縣政府已於112年7月17日訂定發布「宜蘭縣政府處理違反建築法使用管理規定事件統一裁罰基準」，完備制度規章。

        第2則 
        標題：宜蘭縣部分土地未依實際使用情形核課地價稅，審計機關促請改善
        內容： 
        宜蘭縣政府財政稅務局(下稱財稅局)辦理地價稅稅籍清查作業，經審計部臺灣省宜蘭縣審計室查核發現，部分課徵田賦或減免地價稅土地未依實際使用情形改課或恢復課徵地價稅，或非都市計畫公共設施保留地未按一般用地稅率核課地價稅等情事，經函請檢討改善，已釐正稅籍並依法改課或補徵地價稅1,216萬餘元，以維護租稅公平。
        審計室指出，財稅局為健全稅籍、確保稅源及遏止逃漏，以達到公平課稅、增裕庫收目標，每年度訂定地價稅稅籍及使用情形清查作業實施計畫，定期於1月1日起至9月30日止辦理課徵田賦土地、特別稅率用地及減免稅地之清查作業。
        然而，審計室於109年10月運用地理資訊系統(QGIS)與內政部國土測繪中心國土利用調查成果圖進行空間套疊分析查核發現，部分課徵田賦或減免地價稅土地，作為商業、混合使用住宅、製造業、倉儲、停車場等非供農業用途使用，或都市計畫公共設施保留地未按6‰核課地價稅，非屬公共設施保留地未按一般用地稅率核課，或已取得收益之國有土地，未依規定改課或恢復課徵地價稅等，核有短(溢)徵情事，審計室遂於109年12月函請財稅局積極檢討辦理。
        審計室表示，經追蹤改善情形，截至110年1月底止，財稅局已釐正稅籍並依法改課或補徵地價稅共計747筆、金額1,216萬餘元，退還稅款28筆、金額25萬餘元，財稅局將運用QGIS等資訊技術勾稽產出異常資料，列入爾後年度地價稅稅籍清查計畫辦理，以提升清查成效，維護租稅公平。
        
        第3則 
        標題：宜蘭縣五結防潮閘門改善工程一再流標，審計機關促請改善
        內容：
        宜蘭縣政府(下稱縣政府)辦理五結防潮閘門改善工程(下稱閘門改善工程)，經審計部臺灣省宜蘭縣審計室查核發現，縣政府未確認領標廠商未參與投標之原因，致工程發包作業遲未完成，經函請檢討改善，已洽詢原因並經調整招標文件內容後順利完成發包作業，有助閘門改善工程之進行。
        審計室指出，縣政府因冬山河排水系統之五結防潮閘門使用近50年，結構老舊水密性不佳，影響防洪禦潮功能須進行改建，於107年8月委託工程顧問公司辦理規劃設計工作，嗣於110年8月11日完成細部設計審查後，同年12月7日辦理閘門改善工程發包作業，預算金額10億1,283萬餘元，工期1,050日曆天，預定113年11月底完工。
        然而，審計室於111年3月查核發現，閘門改善工程因預算單價偏低，經檢討調整後仍因無廠商參與而流標3次，審計室遂於111年6月函請縣政府檢討妥處，經追蹤結果，縣政府雖已檢討招標文件內容，並調增工程預算為12億6,209萬元，惟因未確認領標廠商未投標之原因，截至112年3月底止，閘門改善工程已連續6次流標，工程發包作業遲未完成，乃於112年5月再函請縣政府積極研謀改善。
        審計室表示，經追蹤改善情形，縣政府已責請工程顧問公司洽詢領標廠商瞭解未參與投標之原因，並據以調整招標文件內容及工程預算單價，公開招標後則積極邀請潛在廠商參與，閘門改善工程已於112年9月13日決標，決標金額12億7,752萬餘元，預計116年6月完工，以確保防洪禦潮功能。

        請將下列的資料內容，仿照上面3則資訊發布的標題與架構內容規則，寫成1則資訊發布：
        
        資料內容如下：
[{原始內容}]
提醒，請注意：
1.簡化標題，標題文字僅簡要敘述查核發現缺失，審計機關促請改善
2.內容共分為4段論述，第1段精簡敘述全貌，要有行政機關作為，「審計部臺灣省宜蘭縣審計室查核發現」及「經函請檢討改善」，機關的改善成果。第2段要有「審計室指出」，說明行政機關相關作為。第3段要有「然而，審計室查核發現」，說明行政機關缺失，審計室函請改善。第4段要有「審計室表示，經追蹤改善情形」，行政機關改善成果。
3.盡量維持審計機關習慣的用語，不要改成白話文。
'''

def 檔案內容轉譯資訊發布提問並複製剪貼簿(檔案):
    from clipboard import copy
    from zhongwen.winman import TEMP, where
    import os
    tmp = TEMP / 'gpt.tmp'
    pandoc = where('pandoc')[0]
    cmd = f'{pandoc} -t plain "{檔案}" -o "{tmp}"'
    os.system(cmd)
    with tmp.open(encoding='utf8') as f:
        content = f.read()
    t = 轉譯資訊發布提問(content)
    copy(t)

def 剪貼簿內容轉譯資訊發布提問():
    from clipboard import paste, copy
    from zhongwen.winman import TEMP, where
    import os
    t = 轉譯資訊發布提問(paste())
    copy(t)
    
def 檔案內容轉譯議會備詢提問並複製剪貼簿(檔案):
    from clipboard import copy
    from zhongwen.winman import TEMP, where
    import os
    tmp = TEMP / 'gpt.tmp'
    pandoc = where('pandoc')[0]
    cmd = f'{pandoc} -t plain "{檔案}" -o "{tmp}"'
    os.system(cmd)
    with tmp.open(encoding='utf8') as f:
        content = f.read()
    t = 轉譯議會備詢提問(content)
    copy(t)
 
def 剪貼簿內容轉譯議會備詢提問():
    from clipboard import paste, copy
    from zhongwen.winman import TEMP, where
    import os
    t = 轉譯議會備詢提問(paste())
    copy(t)
    return t
 
def 設定環境():
    from zhongwen.winman import 增加所有檔案右鍵選單之功能
    from zhongwen.office_document import 設定微軟辦公室軟體共用範本
    from shutil import copy
    import sys
    pythonexe = sys.executable
    cmd = f'"{pythonexe}" -m naotw.gpt --file2news "%1"' 
    增加所有檔案右鍵選單之功能('轉譯資訊發布提問', cmd)
    cmd = f'"{pythonexe}" -m naotw.gpt --file2inquery "%1"' 
    增加所有檔案右鍵選單之功能('轉譯議會備詢提問', cmd)
    設定微軟辦公室軟體共用範本()

if __name__ == '__main__':
    import argparse
    logging.basicConfig(level=logging.INFO)
    parser = argparse.ArgumentParser()
    parser.add_argument("--file2news"
                       ,help="檔案內容轉譯資訊發布提問並複製剪貼簿"
                       ,required=False
                       )
    parser.add_argument("--file2inquery"
                       ,help="檔案內容轉譯轉譯議會備詢提問並複製剪貼簿"
                       ,required=False
                       )
    parser.add_argument("--clipboard2news"
                       ,help="剪貼簿內容轉譯資訊發布提問"
                       ,action='store_true'
                       )
    parser.add_argument("--clipboard2inquery"
                       ,help="剪貼簿內容轉譯議會備詢提問"
                       ,action='store_true'
                       )

    parser.add_argument("--update_office_temp"
                       ,help="更新微軟辦公室軟體共用範本"
                       ,action='store_true'
                       )
    args = parser.parse_args()
    if args.file2news:
        檔案內容轉譯資訊發布提問並複製剪貼簿(args.file2news)
    elif args.file2inquery:
        檔案內容轉譯議會備詢提問並複製剪貼簿(args.file2inquery)
    elif args.clipboard2news:
        剪貼簿內容轉譯資訊發布提問()
    elif args.clipboard2inquery:
        剪貼簿內容轉譯議會備詢提問()
    else:
        設定環境()




def 設定環境():
    import sys 
    cmd = f'"{sys.executable}" "{__file__}" --file2newsquery "%1"'
    增加所有檔案右鍵選單之功能('建置資訊發布提問', cmd)

def 增加所有檔案右鍵選單之功能(功能名稱:str, 指令:str):
    import winreg as reg
    import os
    import sys

    # 功能名稱
    context_menu_name = 功能名稱
    
    key_path = fr'*\shell\{context_menu_name}'
    command_key_path = fr'*\shell\{context_menu_name}\command'

    # 創建註冊表項目
    try:
        reg.CreateKey(reg.HKEY_CLASSES_ROOT, key_path)
        reg.CreateKey(reg.HKEY_CLASSES_ROOT, command_key_path)
        
        # 設置右鍵選單項目名稱
        with reg.OpenKey(reg.HKEY_CLASSES_ROOT, key_path, 0, reg.KEY_WRITE) as key:
            reg.SetValue(key, '', reg.REG_SZ, context_menu_name)

        # 設置指令
        with reg.OpenKey(reg.HKEY_CLASSES_ROOT, command_key_path, 0, reg.KEY_WRITE) as key:
            reg.SetValue(key, '', reg.REG_SZ, 指令)
        print(f"所有檔案右鍵選單增加【{功能名稱}】項目。")
    except Exception as e:
        print(f"添加右鍵選單項目時出錯: {e}")

def 建置資訊發布提問至剪貼簿(內容):
    '資訊發布'
    from clipboard import copy
    提問 = f'''"
        在台灣，請用繁體中文回答。以下我將提供審計部臺灣省宜蘭縣審計室對於追蹤查核意見後續改善情形後，所辦理的3則資訊發布標題與架構內容給您參考。

        第1則 
        標題：宜蘭縣部分建築物公共安全及消防安全檢查作業未臻周妥，審計機關促請改善
        內容：
        宜蘭縣政府(下稱縣政府)及所屬消防局(下稱消防局)執行建築物公共安全及消防安全檢查作業，經審計部臺灣省宜蘭縣審計室查核發現，部分供公眾使用之建築物有逾期或漏未申報公共安全或消防安全設備檢查，及停歇業場所未予列管等情事，經函請檢討改善，已完成建築物(場所)申報及加強停歇業場所之列管與追蹤，並訂定統一裁罰基準，保障民眾生命財產及維護公共安全。
        審計室指出，依建築法第77條第3項規定，供公眾使用之建築物，應由建築物所有權人、使用人定期委託中央主管建築機關認可之專業機構或人員檢查簽證，其檢查簽證結果應向當地主管建築機關申報；消防法第9條第1項規定，各類場所之管理權人，應定期檢修消防安全設備；其檢修結果，應依規定期限報請場所所在地主管機關審核，場所有歇業或停業之情形者，亦同。截至111年底止，縣政府及消防局列管應申報建築物公共安全及消防安全檢查之建築物或場所，計有6,547處及11,084處。
        然而，審計室於112年2月查核發現，列管項目中逾期未完成建築物公共安全申報者16處、漏未申報建築物公共安全者有10處、漏未申報消防安全設備檢查者有4處，又對於違反上述有關建築法之規定者，尚未訂定統一裁罰基準，另消防局對於停歇業場所及其使用現況尚無列管資料，管理作業有欠周妥，審計室遂於112年3月函請縣政府及消防局檢討改善。
        審計室表示，經追蹤改善情形，縣政府及消防局已督促所有權人或管理權人等依規定辦理申報，截至112年底止，上述30處逾期或漏未申報者均已完成申報審查作業；又停歇業場所經清查後，計有253處均已列管追蹤使用情形，保障民眾生命財產及維護公共安全。另縣政府已於112年7月17日訂定發布「宜蘭縣政府處理違反建築法使用管理規定事件統一裁罰基準」，完備制度規章。

        第2則 
        標題：宜蘭縣部分土地未依實際使用情形核課地價稅，審計機關促請改善
        內容： 
        宜蘭縣政府財政稅務局(下稱財稅局)辦理地價稅稅籍清查作業，經審計部臺灣省宜蘭縣審計室查核發現，部分課徵田賦或減免地價稅土地未依實際使用情形改課或恢復課徵地價稅，或非都市計畫公共設施保留地未按一般用地稅率核課地價稅等情事，經函請檢討改善，已釐正稅籍並依法改課或補徵地價稅1,216萬餘元，以維護租稅公平。
        審計室指出，財稅局為健全稅籍、確保稅源及遏止逃漏，以達到公平課稅、增裕庫收目標，每年度訂定地價稅稅籍及使用情形清查作業實施計畫，定期於1月1日起至9月30日止辦理課徵田賦土地、特別稅率用地及減免稅地之清查作業。
        然而，審計室於109年10月運用地理資訊系統(QGIS)與內政部國土測繪中心國土利用調查成果圖進行空間套疊分析查核發現，部分課徵田賦或減免地價稅土地，作為商業、混合使用住宅、製造業、倉儲、停車場等非供農業用途使用，或都市計畫公共設施保留地未按6‰核課地價稅，非屬公共設施保留地未按一般用地稅率核課，或已取得收益之國有土地，未依規定改課或恢復課徵地價稅等，核有短(溢)徵情事，審計室遂於109年12月函請財稅局積極檢討辦理。
        審計室表示，經追蹤改善情形，截至110年1月底止，財稅局已釐正稅籍並依法改課或補徵地價稅共計747筆、金額1,216萬餘元，退還稅款28筆、金額25萬餘元，財稅局將運用QGIS等資訊技術勾稽產出異常資料，列入爾後年度地價稅稅籍清查計畫辦理，以提升清查成效，維護租稅公平。
        
        第3則 
        標題：宜蘭縣五結防潮閘門改善工程一再流標，審計機關促請改善
        內容：
        宜蘭縣政府(下稱縣政府)辦理五結防潮閘門改善工程(下稱閘門改善工程)，經審計部臺灣省宜蘭縣審計室查核發現，縣政府未確認領標廠商未參與投標之原因，致工程發包作業遲未完成，經函請檢討改善，已洽詢原因並經調整招標文件內容後順利完成發包作業，有助閘門改善工程之進行。
        審計室指出，縣政府因冬山河排水系統之五結防潮閘門使用近50年，結構老舊水密性不佳，影響防洪禦潮功能須進行改建，於107年8月委託工程顧問公司辦理規劃設計工作，嗣於110年8月11日完成細部設計審查後，同年12月7日辦理閘門改善工程發包作業，預算金額10億1,283萬餘元，工期1,050日曆天，預定113年11月底完工。
        然而，審計室於111年3月查核發現，閘門改善工程因預算單價偏低，經檢討調整後仍因無廠商參與而流標3次，審計室遂於111年6月函請縣政府檢討妥處，經追蹤結果，縣政府雖已檢討招標文件內容，並調增工程預算為12億6,209萬元，惟因未確認領標廠商未投標之原因，截至112年3月底止，閘門改善工程已連續6次流標，工程發包作業遲未完成，乃於112年5月再函請縣政府積極研謀改善。
        審計室表示，經追蹤改善情形，縣政府已責請工程顧問公司洽詢領標廠商瞭解未參與投標之原因，並據以調整招標文件內容及工程預算單價，公開招標後則積極邀請潛在廠商參與，閘門改善工程已於112年9月13日決標，決標金額12億7,752萬餘元，預計116年6月完工，以確保防洪禦潮功能。

        請將下列的資料內容，仿照上面3則資訊發布的標題與架構內容規則，寫成1則資訊發布：
        
        資料內容如下：
[
{內容}
]
提醒，請注意：
1.簡化標題，標題文字僅簡要敘述查核發現缺失，審計機關促請改善
2.內容共分為4段論述，第1段精簡敘述全貌，要有行政機關作為，「審計部臺灣省宜蘭縣審計室查核發現」及「經函請檢討改善」，機關的改善成果。第2段要有「審計室指出」，說明行政機關相關作為。第3段要有「然而，審計室查核發現」，說明行政機關缺失，審計室函請改善。第4段要有「審計室表示，經追蹤改善情形」，行政機關改善成果。
3.盡量維持審計機關習慣的用語，不要改成白話文。
"'''
    copy(提問)

def 自檔案建置資訊發布提問(檔案路徑):
    from pathlib import Path
    建置資訊發布提問至剪貼簿(Path(檔案路徑).read_text(encoding='utf8'))

if __name__ == '__main__':
    import argparse
    import time
    import sys
    parser = argparse.ArgumentParser()
    parser.add_argument("--file2newsquery", help="自檔案建置資訊發布提問")
    args = parser.parse_args()
    if args.file2newsquery:
        自檔案建置資訊發布提問(args.file2newsquery)
        sys.exit()
    設定環境()
